<?php
include 'includes/session.php';

ob_start(); // Start output buffering

// require('path/to/fpdf.php');  // Adjust the path as needed
require_once('../tcpdf/tcpdf.php');

// Get Election Title
// Load voting title from configuration
$parse = parse_ini_file('config.ini', FALSE, INI_SCANNER_RAW);
$election_title = $parse['election_title'];

// Get Admin Name
$admin_query = $conn->query("SELECT firstname, lastname FROM admin");
$admin_name = $admin_query->fetch_assoc();
$admin = $admin_name['firstname'] . ' ' . $admin_name['lastname'];

// Get Voting Schedule
$schedule_query = $conn->query("SELECT start_date, end_date FROM schedule");
$schedule = $schedule_query->fetch_assoc();
$start_time = $schedule['start_date'];
$end_time = $schedule['end_date'];


// Get Number of Positions
$positions_query = $conn->query("SELECT COUNT(*) as total_positions FROM positions");
$positions = $positions_query->fetch_assoc()['total_positions'];

// Get Number of Candidates
$candidates_query = $conn->query("SELECT COUNT(*) as total_candidates FROM candidates");
$candidates = $candidates_query->fetch_assoc()['total_candidates'];


// Get Total Registered Voters
$total_voters_query = $conn->query("SELECT COUNT(*) as total_voters FROM voters");
$total_voters = $total_voters_query->fetch_assoc()['total_voters'];

// Get Voters Who Voted
$voted_query = $conn->query("SELECT COUNT(DISTINCT voters_reg_no) as total_voted FROM votes");
$total_voted = $voted_query->fetch_assoc()['total_voted'];

// Calculate Voters Who Did Not Vote
$did_not_vote = $total_voters - $total_voted;


// Initialize FPDF
$pdf = new TCPDF();
$pdf->AddPage();
$pdf->SetFont('helvetica', 'B', 16);
$pdf->SetTitle('Overall KAYE Voting Summary: ' . $election_title);

// Generate content for the PDF
$header = '
		<div style="width: 90%; margin: auto; text-align: center;"> 
        <img src="../images/favicon.jpg" style="border-radius: 50%; height: 70px; width: 70px; padding: 1px;"> <br>
  		<span style="color: maroon; font-size: 16px; margin-bottom: 4px;"><b>AFRICA RENEWAL UNIVERSITY</b></span> <br>
  		<span style="color: maroon; font-size: 14px; margin-bottom: 4px;"><b>KAYE ONLINE VOTING</b> - ELECTION RESULTS</span> <br>
        <h3>' . $election_title . ' - ELECTION SUMMARY</h3>
          
  		<hr style=" height: 2px; color: maroon;">
		</div>

      ';
$pdf->writeHTML($header);


/////////////////////
// Election Title
$pdf->SetFont('helvetica', 'B', 12);
$pdf->Cell(0, 10, 'ELECTION TITLE', 0, 1);
$pdf->SetFont('helvetica', '', 12);
$pdf->Cell(140, 10, $election_title, 1, 1);


/////////////////////////
// Voting Schedule Table
$pdf->Ln(10);  // Add line break
$pdf->SetFont('helvetica', 'B', 12);
$pdf->Cell(0, 10, 'VOTING SCHEDULED TIME', 0, 1);
$pdf->SetFont('helvetica', '', 12);
$pdf->Cell(90, 10, 'Voting Starting Date and Time', 1);
$pdf->Cell(50, 10, $start_time, 1, 1);
$pdf->Cell(90, 10, 'Voting Ending Date and Time', 1);
$pdf->Cell(50, 10, $end_time, 1, 1);



////////////////////////////////////////////////
// Number of Positions Table
$pdf->Ln(10);  // Add line break
$pdf->SetFont('helvetica', 'B', 12);
$pdf->Cell(0, 10, 'POSITION SUMMARY', 0, 1);
$pdf->SetFont('helvetica', '', 12);
$pdf->Cell(90, 10, 'Total Positions registered', 1);
$pdf->Cell(50, 10, $positions, 1, 1);


/////////////////////////////////////////////
// Positions Table
$all_positions_query = $conn->query("SELECT * FROM positions ORDER BY priority ASC");

$pdf->Ln(3);  // Add line break
$pdf->SetFont('helvetica', 'B', 12);
$pdf->Cell(140, 10, 'DESCRIPTION', 1, 1);

while ($all_positions = $all_positions_query->fetch_assoc()) {
    $description = $all_positions['description'];

    $pdf->SetFont('helvetica', '', 10);
    $pdf->Cell(140, 10, $description, 1, 1);
}



////////////////////////////////////////////////
// Number of candidates Table
$pdf->Ln(10);  // Add line break
$pdf->SetFont('helvetica', 'B', 12);
$pdf->Cell(0, 10, 'CANDIDATES SUMMARY', 0, 1);
$pdf->SetFont('helvetica', '', 12);
$pdf->Cell(70, 10, 'Total Candidates registered', 1);
$pdf->Cell(70, 10, $candidates, 1, 1);


/////////////////////////////////////////////
// candidates Table
$all_candidates_query = $conn->query(
    "SELECT * FROM candidates LEFT JOIN positions ON positions.id=candidates.position_id ORDER BY positions.priority ASC"
);

$pdf->Ln(3);  // Add line break
$pdf->SetFont('helvetica', 'B', 12);
$pdf->Cell(70, 10, 'CANDIDATE NAME', 1);
$pdf->Cell(70, 10, 'POSITION', 1, 1);

while ($all_candidates = $all_candidates_query->fetch_assoc()) {
    $fullname = $all_candidates['firstname'] . ' ' . $all_candidates['lastname'];
    $position = $all_candidates['description'];

    $pdf->SetFont('helvetica', '', 10);
    $pdf->Cell(70, 10, $fullname, 1);
    $pdf->Cell(70, 10, $position, 1, 1);
}



///////////////////////////////////////////
// Voters Summary Table
$pdf->Ln(10);  // Add line break
$pdf->SetFont('helvetica', 'B', 12);
$pdf->Cell(0, 10, 'VOTERS SUMMARY', 0, 1);
$pdf->SetFont('helvetica', '', 12);
$pdf->Cell(90, 10, 'Total Numbers of Registered Voters', 1);
$pdf->Cell(50, 10, $total_voters, 1, 1);
$pdf->Cell(90, 10, 'Total Numbers of Voters Who Voted', 1);
$pdf->Cell(50, 10, $total_voted, 1, 1);
$pdf->Cell(90, 10, 'Total Numbers of Voters Who Did Not Vote', 1);
$pdf->Cell(50, 10, $did_not_vote, 1, 1);



//////////////////////////////////////////////////
// Add footer with extraction time
// set the time time zone to kampala (East Africa Time Zone);
date_default_timezone_set('Africa/Kampala');
$date = date('l, F j, Y g:i A');

$footer = '
    <br><br><br><br><br>
    <hr>
        <span style="font-size: 10px;">
            Extracted on: ' . $date . ' | Voting conducted by ' . $admin . '.
        </span>
';
$pdf->writeHTMLCell(0, 0, '', '', $footer, 0, 1, 0, true, true);


// Output the PDF
$pdf->Output('Overall Election Summary - KAYE Online Voting.pdf');
