<?php
include 'includes/session.php';

/**
 * Processes a CSV file containing voter data and adds new voters to the database.
 * 
 * This function handles the upload and processing of a CSV file containing voter
 * registration data. It reads each row of the CSV file, extracts the relevant
 * data, and checks if the voter already exists in the database. If the voter
 * does not exist, it inserts the new voter into the database. If the voter
 * already exists, it tracks the skipped voter and the reason for skipping.
 * 
 * The function also updates the session with success and error messages
 * based on the results of the CSV file processing.
 */
if (isset($_FILES['csv_file']['name'])) {
    $fileName = $_FILES['csv_file']['tmp_name'];
    $fileType = $_FILES['csv_file']['type'];

    // Check if the file is CSV
    if ($fileType !== 'text/csv' && $fileType !== 'application/vnd.ms-excel') {
        $_SESSION['error'] = 'Please upload a valid CSV file.';
        header('location: voters.php');
        exit();
    }


    if ($_FILES['csv_file']['size'] > 0) {
        $file = fopen($fileName, 'r');

        // Get the header row and validate the columns
        $header = fgetcsv($file);
        $expected_header = ['voters_reg_no','password', 'firstname', 'lastname', 'email', 'photo'];

        // Check if the headers match
        if ($header !== $expected_header) {
            $_SESSION['error'] = 'CSV headers/titles do not match the expected format.';
            fclose($file);
            header('location: voters.php');
            exit();
        }

        // Track skipped voters and errors
        $skipped = [];
        $success_count = 0;

        // Process each row of the CSV file
        while (($row = fgetcsv($file, 10000, ",")) !== FALSE) {
            
            // Validate that the row has the expected number of columns
            // if (count($row) < 9) {
            //     $skipped[] = "Incomplete data in one of the rows.";
            //     continue; // Skip this row and move to the next
            // }

            // Extract data from each row
            $reg_no = $conn->real_escape_string($row[0]);
            $password = password_hash($conn->real_escape_string($row[1]), PASSWORD_DEFAULT); // hash the password
            $first_name = $conn->real_escape_string($row[2]);
            $last_name = $conn->real_escape_string($row[3]);
            $email = $conn->real_escape_string($row[4]);
            $photo = $conn->real_escape_string($row[5]);

            // Check if registration number or email already exists
            $check_sql = "SELECT * FROM voters WHERE voters_reg_no = '$reg_no' OR email = '$email'";
            $check_query = $conn->query($check_sql);

            if ($check_query->num_rows > 0) {
                // Voter already exists, track the skipped one
                $existing_voter = $check_query->fetch_assoc();
                if (
                    $existing_voter['voters_reg_no'] === $reg_no
                ) {
                    $skipped[] = "Voter with registration number '$reg_no' already exists.";
                }
                if ($existing_voter['email'] === $email) {
                    $skipped[] = "Voter with email '$email' already exists.";
                }
            } else {
                // Insert new voter into the database
                $sql = "INSERT INTO Voters (voters_reg_no, password, firstname, lastname, email, photo)
                    VALUES ('$reg_no', '$password', '$first_name', '$last_name', '$email', '$photo')";

                if ($conn->query($sql)) {
                    $success_count++;
                } else {
                    $skipped[] = "Error inserting voter with registration number '$reg_no'.";
                }
            }
        }

        fclose($file);

        // Display success message for added voters
        if ($success_count > 0) {
            $_SESSION['success'] = "$success_count voters added successfully.";
        }

        // Display error message for skipped voters
        if (count($skipped) > 0) {
            $_SESSION['error'] = implode('<br>', $skipped);
        }
    } else {
        $_SESSION['error'] = 'Please upload a non-empty CSV file.';
    }
} else {
    $_SESSION['error'] = 'No file uploaded. Please try again.';
}

header('location: voters.php');
$conn->close();
?>
